<a href="https://github.com/christinahedges/lamatrix/actions/workflows/tests.yml"><img src="https://github.com/christinahedges/lamatrix/workflows/pytest/badge.svg" alt="Test status"/></a> [![Generic badge](https://img.shields.io/badge/documentation-live-blue.svg)](https://christinahedges.github.io/lamatrix/)
[![PyPI version](https://badge.fury.io/py/lamatrix.svg)](https://badge.fury.io/py/lamatrix)

<p align="center">
  <img src="https://github.com/christinahedges/lamatrix/blob/main/docs/images/logo.png?raw=true" width="350" alt="lamatrix logo">
</p>

# LAmatrix

This package is designed to help you fit linear algebra models to data. It's designed to eventually replace `Lightkurve.design_matrix` and `Lightkurve.Corrector` objects.
